@@ -130,6 +130,7 @@ def process_phonenumber(
     numberfmt: str = 'international',
     checkonly: bool = False,
     empty_if_invalid: bool = False,
+    omit_error_str: bool = False,
     country=mycountry
 ) -> Union[str, bool]:
     """ Checks if a phonenumber is valid returns in specified format.
@@ -182,4 +183,51 @@ def process_phonenumber(
         return phonenumbers.format_number(
             pn,
             phonefmt
-        ) + error_str
+        ) + (error_str if not omit_error_str else '')
+
+
+def compare_phonenumbers(
+    number1: str,
+    number2: str,
+    numberfmt: str = 'international',
+    country=mycountry,
+    ignore_invalid: bool = True
+) -> bool:
+    """ Compares two phone numbers, returns True if they are identical
+
+    :param number1: phone number string to be processed
+    :param number2: phone number string to be processed
+    :param numberfmt: format in which the numbers are processed
+
+        * international (default)
+        * national
+        * E164 (international, condensed)
+    """
+    number1_processed = process_phonenumber(
+        number1,
+        numberfmt=numberfmt,
+        omit_error_str=ignore_invalid,
+        country=country
+    )
+    number2_processed = process_phonenumber(
+        number2,
+        numberfmt=numberfmt,
+        omit_error_str=ignore_invalid,
+        country=country
+    )
+
+    if not ignore_invalid:  # only for better perfomance
+        for error_str in ('invalid', 'impossible', 'not a phone number'):
+            if error_str in number1_processed or error_str in number2_processed:
+                return False
+
+    is_equal = False
+    if number1_processed and number2_processed:
+        is_equal = number1_processed == number2_processed
+
+    if not is_equal:  # try another route
+        number1 = ''.join(c for c in number1 if c in '01234567890').lstrip('0')
+        number2 = ''.join(c for c in number2 if c in '01234567890').lstrip('0')
+        is_equal = number1 == number2
+
+    return is_equal
